@@ -1,3 +1,4 @@
+CLOSE_NOW = 'close'
 POWER_BUTTON_PIN          =3
 POWER_BUTTON_HOLD_TIME    =3
 DEVICE_POLLING_TIME       =1
@@ -44,6 +45,9 @@ DEVICE_STATE_TAKING_PHOTO        = 0xE2
 DEVICE_STATE_I2C_ERROR           = 0xE3
 DEVICE_STATE_EXCEPTION           = 0xE4
 
+#DEVICE_STATE_SHUT_DOWN           = 0xEF
+
+
 CASSETTE_STATUS_FLAG     = 0x80
 CASSETTE_STATUS = [
                     DEVICE_STATE_CASSETTE_VALID,
